from .. import Provider as PersonProvider


class Provider(PersonProvider):
    formats_male = (
        "{{first_name_male}} {{last_name_male}}",
        "{{first_name_male}} {{last_name_male}}",
        "{{first_name_male}} {{last_name_male}}",
        "{{first_name_male}} {{last_name_male}}",
        "{{first_name_male}} {{last_name_male}}",
        "{{first_name_male}} {{last_name_male}}",
        "{{first_name_male}}-{{first_name_male}} {{last_name_male}}",
    )

    formats_female = (
        "{{first_name_female}} {{last_name_female}}",
        "{{first_name_female}} {{last_name_female}}",
        "{{first_name_female}} {{last_name_female}}",
        "{{first_name_female}} {{last_name_female}}",
        "{{first_name_female}} {{last_name_female}}",
        "{{first_name_female}} {{last_name_female}}",
        "{{first_name_female}}-{{first_name_female}} {{last_name_female}}",
    )

    formats = formats_male + formats_female

    first_names_male = (
        "Άγγελος",
        "Άνθιμος",
        "Άρης",
        "Άριστος",
        "Έκτορας",
        "Έξαρχος",
        "Ίκαρος",
        "Ίων",
        "Αίας",
        "Αβραάμ",
        "Αγάπιος",
        "Αγαθάγγελος",
        "Αγαθοκλής",
        "Αγαθόνικος",
        "Αγαμέμνων",
        "Αγαπητός",
        "Αγγελής",
        "Αγησίλαος",
        "Αδάμ",
        "Αδαμάντιος",
        "Αθανάσιος",
        "Αθηναγόρας",
        "Αθηνόδωρος",
        "Αιμίλιος",
        "Αιμιλιανός",
        "Ακρίτας",
        "Ακριβός",
        "Αλέξανδρος",
        "Αλέξιος",
        "Αλκιβιάδης",
        "Αμβρόσιος",
        "Ανάργυρος",
        "Ανέστης",
        "Αναγνώστης",
        "Ανανίας",
        "Αναξαγόρας",
        "Αναστάσιος",
        "Ανδρέας",
        "Ανδροκλής",
        "Ανδρόνικος",
        "Ανθούλης",
        "Αντίγονος",
        "Αντίπατρος",
        "Αντύπας",
        "Αντώνιος",
        "Απόλλων",
        "Απόστολος",
        "Αρίσταρχος",
        "Αργύριος",
        "Αριστείδης",
        "Αριστομένης",
        "Αριστοτέλης",
        "Αριστοφάνης",
        "Αριστόβουλος",
        "Αρτέμης",
        "Αρτέμιος",
        "Αρχέλαος",
        "Αρχιμήδης",
        "Ασημάκης",
        "Ασημής",
        "Ασκληπιός",
        "Αστέριος",
        "Αυγέρης",
        "Αυξέντιος",
        "Αφέντης",
        "Αχιλλέας",
        "Αύγουστος",
        "Βάιος",
        "Βαλάντης",
        "Βαλέριος",
        "Βαλεντίνος",
        "Βαρδής",
        "Βαρθολομαίος",
        "Βαρσάμος",
        "Βασίλειος",
        "Βασίλης",
        "Βελισσάριος",
        "Βενέτιος",
        "Βενιαμίν",
        "Βενιζέλος",
        "Βησσαρίων",
        "Βικέντιος",
        "Βλάσης",
        "Βλάσιος",
        "Βλαδίμηρος",
        "Βρασίδας",
        "Βύρων",
        "Γαβριήλ",
        "Γαλάτιος",
        "Γαληνός",
        "Γαρύφαλλος",
        "Γεράσιμος",
        "Γεώργιος",
        "Γιάννης",
        "Γιώργος",
        "Γκίκας",
        "Γρηγόριος",
        "Δήμος",
        "Δίκαιος",
        "Δαμασκηνός",
        "Δαμιανός",
        "Δανιήλ",
        "Δημήτρης",
        "Δημήτριος",
        "Δημοκράτης",
        "Δημοσθένης",
        "Δημόκριτος",
        "Διαμαντής",
        "Διογένης",
        "Διομήδης",
        "Διονύσιος",
        "Δομήνικος",
        "Δράκων",
        "Δρόσος",
        "Δωρόθεος",
        "Ειρηναίος",
        "Ελευθέριος",
        "Ελισσαίος",
        "Εμμανουήλ",
        "Επαμεινώνδας",
        "Ερμής",
        "Ερμόλαος",
        "Ερρίκος",
        "Ερωτόκριτος",
        "Ευάγγελος",
        "Ευγένιος",
        "Ευδόξιος",
        "Ευθύμιος",
        "Ευκλείδης",
        "Ευμένιος",
        "Ευριπίδης",
        "Ευσέβιος",
        "Ευστάθιος",
        "Ευστράτιος",
        "Ευτύχιος",
        "Εφραίμ",
        "Ζήνων",
        "Ζαφείρης",
        "Ζαφείριος",
        "Ζαχαρίας",
        "Ζηνόβιος",
        "Ηλίας",
        "Ηρακλής",
        "Ηρόδοτος",
        "Ησαΐας",
        "Θέμης",
        "Θαλής",
        "Θεμιστοκλής",
        "Θεοδόσης",
        "Θεοδόσιος",
        "Θεολόγος",
        "Θεοτόκης",
        "Θεοφάνης",
        "Θεοφύλακτος",
        "Θεοχάρης",
        "Θεόδουλος",
        "Θεόδωρος",
        "Θεόκλητος",
        "Θεόπιστος",
        "Θεόφιλος",
        "Θεόφραστος",
        "Θησεύς",
        "Θουκυδίδης",
        "Θρασύβουλος",
        "Θωμάς",
        "Ιάκωβος",
        "Ιάσονας",
        "Ιάσων",
        "Ιγνάτιος",
        "Ιερεμίας",
        "Ιερόθεος",
        "Ιερώνυμος",
        "Ιορδάνης",
        "Ιουλιανός",
        "Ιούλιος",
        "Ιπποκράτης",
        "Ιππόλυτος",
        "Ισίδωρος",
        "Ισαάκ",
        "Ιωάννης",
        "Ιωακείμ",
        "Ιωνάς",
        "Ιωσήφ",
        "Κάρολος",
        "Κίμων",
        "Καλλίνικος",
        "Κηρύκος",
        "Κλέαρχος",
        "Κλήμης",
        "Κλεάνθης",
        "Κλεομένης",
        "Κλεόβουλος",
        "Κλεόπας",
        "Κομνηνός",
        "Κορνήλιος",
        "Κοσμάς",
        "Κρυστάλλης",
        "Κυπριανός",
        "Κυριάκος",
        "Κυριαζής",
        "Κωνσταντίνος",
        "Κύρος",
        "Κώστας",
        "Λάζαρος",
        "Λάμπρος",
        "Λάσκαρης",
        "Λέανδρος",
        "Λέων",
        "Λαέρτης",
        "Λαοκράτης",
        "Λαυρέντιος",
        "Λεμονής",
        "Λεονάρδος",
        "Λεωνίδας",
        "Λογοθέτης",
        "Λουδοβίκος",
        "Λουκάς",
        "Λουκιανός",
        "Λυκούργος",
        "Λύσανδρος",
        "Μάριος",
        "Μάρκος",
        "Μένανδρος",
        "Μίνωας",
        "Μαγδαληνός",
        "Μακάριος",
        "Μαρίνος",
        "Μαρτίνος",
        "Ματθαίος",
        "Μαυρίκιος",
        "Μαυροειδής",
        "Μαυρούδης",
        "Μαύρος",
        "Μεγακλής",
        "Μεθόδιος",
        "Μελέτιος",
        "Μενέλαος",
        "Μερκούριος",
        "Μηνάς",
        "Μικές",
        "Μιλτιάδης",
        "Μιχάλης",
        "Μιχαήλ",
        "Νέαρχος",
        "Νίκανδρος",
        "Νίκος",
        "Νίκων",
        "Ναθαναήλ",
        "Ναπολέων",
        "Νεκτάριος",
        "Νεοκλής",
        "Νεόφυτος",
        "Νικήτας",
        "Νικηφόρος",
        "Νικόδημος",
        "Νικόλαος",
        "Ξανθός",
        "Ξενοφών",
        "Οδυσσέας",
        "Οδυσσεύς",
        "Ορέστης",
        "Ορφέας",
        "Πάρις",
        "Πάτροκλος",
        "Πέτρος",
        "Πίνδαρος",
        "Παναγής",
        "Παναγιώτης",
        "Πανορμίτης",
        "Πανταζής",
        "Παντελής",
        "Παντελεήμων",
        "Παράσχος",
        "Παρασκευάς",
        "Πασχάλης",
        "Παυσανίας",
        "Παύλος",
        "Πελοπίδας",
        "Περικλής",
        "Πλάτων",
        "Πλούταρχος",
        "Πολυζώης",
        "Πολυκράτης",
        "Πολυχρόνιος",
        "Πολύβιος",
        "Πολύδωρος",
        "Πολύκαρπος",
        "Πραξιτέλης",
        "Προκόπιος",
        "Προμηθέας",
        "Πρόδρομος",
        "Πυθαγόρας",
        "Πύρρος",
        "Ράλλης",
        "Ρήγας",
        "Ρίζος",
        "Ραφαήλ",
        "Ραχήλ",
        "Ροδόφλος",
        "Ρωμανός",
        "Σάββας",
        "Σέργιος",
        "Σαμουήλ",
        "Σαράντης",
        "Σεβαστιανός",
        "Σεραφείμ",
        "Σιρανούς",
        "Σολομών",
        "Σοφοκλής",
        "Σπήλιος",
        "Σπυρίδων",
        "Στέλλιος",
        "Στέργιος",
        "Στέφανος",
        "Σταμάτης",
        "Σταμάτιος",
        "Σταύρος",
        "Στυλιανός",
        "Συμεών",
        "Σωκράτης",
        "Σωτήρης",
        "Σωτήριος",
        "Σόλων",
        "Σώζων",
        "Τίμων",
        "Τίτος",
        "Ταξίαρχος",
        "Ταξιάρχης",
        "Τζανέτος",
        "Τηλέμαχος",
        "Τηλεμαχος",
        "Τιμολέων",
        "Τιμόθεος",
        "Τριαντάφυλλος",
        "Τρύφων",
        "Τσαμπίκος",
        "Υάκινθος",
        "Φίλιππος",
        "Φαίδων",
        "Φανούριος",
        "Φιλήμων",
        "Φλοριάντ",
        "Φοίβος",
        "Φρίξος",
        "Φραγκίσκος",
        "Φρειδερίκος",
        "Φωκάς",
        "Φωκίων",
        "Φωτεινός",
        "Φώτιος",
        "Χάρις",
        "Χαράλαμπος",
        "Χαρίλαος",
        "Χαρίτος",
        "Χρήστος",
        "Χρίστος",
        "Χριστιάν",
        "Χριστόδουλος",
        "Χριστόφορος",
        "Χρυσοβαλάντιος",
        "Χρυσόστομος",
        "Χρύσανθος",
        "Όθων",
        "Όμηρος",
    )

    first_names_female = (
        "Άλκηστις",
        "Άννα",
        "Άρτεμις",
        "Έλλη",
        "Ήβη",
        "Ήλια",
        "Ήρα",
        "Ίρις",
        "Αγάθη",
        "Αγάπη",
        "Αγαθή",
        "Αγγελική",
        "Αγλαΐα",
        "Αγνή",
        "Αγόρω",
        "Αδαμαντία",
        "Αηδόνα",
        "Αθανασία",
        "Αθηνά",
        "Αθηνοδώρα",
        "Αικατερίνη",
        "Αιμιλία",
        "Ακριβή",
        "Αλίκη",
        "Αλεξάνδρα",
        "Αλεξία",
        "Αλκινόη",
        "Αλκμήνη",
        "Αμαλία",
        "Αμβροσία",
        "Αμφιθέα",
        "Αμφιτρίτη",
        "Ανάργυρη",
        "Αναστασία",
        "Ανατολή",
        "Ανδριανή",
        "Ανδρομάχη",
        "Ανδρομέδα",
        "Ανδρονίκη",
        "Ανθή",
        "Ανθούλα",
        "Αννίκα",
        "Αντιγόνη",
        "Αντωνία",
        "Απολλωνία",
        "Αποστολία",
        "Αρέθα",
        "Αργυρούλα",
        "Αργυρώ",
        "Αρετή",
        "Αριάδνη",
        "Αριστέα",
        "Αρτεμισία",
        "Αρχοντία",
        "Ασημίνα",
        "Ασημούλα",
        "Ασπασία",
        "Αστέρω",
        "Αταλάντη",
        "Αυγή",
        "Αυγουστίνα",
        "Αφέντρα",
        "Αφροδίτη",
        "Αχιλλεία",
        "Βάγια",
        "Βέρα",
        "Βαγιανή",
        "Βαλάντω",
        "Βαλέρια",
        "Βαλεντίνα",
        "Βαρβάρα",
        "Βαρσαμία",
        "Βασιλεία",
        "Βασιλική",
        "Βεατρίκη",
        "Βελισσαρία",
        "Βενετία",
        "Βερονίκη",
        "Βερόνικα",
        "Βησσαρία",
        "Βικέντια",
        "Βικτωρία",
        "Βικτόρια",
        "Βιολέτα",
        "Βιργινία",
        "Βλασία",
        "Βρυσηίς",
        "Γαβριέλλα",
        "Γαλάτεια",
        "Γαλήνη",
        "Γαρυφαλλιά",
        "Γενοβέφα",
        "Γερακίνα",
        "Γερασιμούλα",
        "Γεσθημανή",
        "Γεωργία",
        "Γιαννούλα",
        "Γιασεμή",
        "Γιολάντα",
        "Γκόλφω",
        "Γλαύκη",
        "Γλυκερία",
        "Γραμματική",
        "Δάφνη",
        "Δέσποινα",
        "Δήμητρα",
        "Δαβιδούλα",
        "Δαμασκηνή",
        "Δαμιανή",
        "Δανάη",
        "Δημούλα",
        "Διαλεκτή",
        "Διαμάντω",
        "Διαμαντούλα",
        "Διδώ",
        "Δικαία",
        "Διονυσία",
        "Δούκισσα",
        "Δροσιά",
        "Δωροθέα",
        "Δόμνα",
        "Ειρήνη",
        "Ελένη",
        "Ελέσσα",
        "Ελεονόρα",
        "Ελευθερία",
        "Ελισάβετ",
        "Ελπίδα",
        "Ελπίς",
        "Εμμανουέλα",
        "Επιστήμη",
        "Ερασμία",
        "Ερατώ",
        "Εριέτα",
        "Εριφύλη",
        "Ερμιόνη",
        "Ερωφίλη",
        "Ευαγγελία",
        "Ευανθία",
        "Ευγενία",
        "Ευδοκία",
        "Ευδοξία",
        "Ευθαλία",
        "Ευθυμία",
        "Ευλαμπία",
        "Ευμορφία",
        "Ευπραξία",
        "Ευρυδίκη",
        "Ευρύκλεια",
        "Ευσεβία",
        "Ευσεβεία",
        "Ευσταθία",
        "Ευστρατία",
        "Ευτέρπη",
        "Ευτυχία",
        "Ευφροσύνη",
        "Εύα",
        "Εύκλεια",
        "Ζαμπέτα",
        "Ζαμπία",
        "Ζαφειρία",
        "Ζαχαρένια",
        "Ζαχαρούλα",
        "Ζηναϊς",
        "Ζηνοβία",
        "Ζησούλα",
        "Ζωή",
        "Ηλέκτρα",
        "Ηλιάνα",
        "Ηράκλεια",
        "Ηώ",
        "Θάλεια",
        "Θέκλα",
        "Θέμις",
        "Θέτις",
        "Θαλασσινή",
        "Θεανώ",
        "Θεμιστόκλεια",
        "Θεοδοσία",
        "Θεοδούλη",
        "Θεοδότη",
        "Θεοδώρα",
        "Θεολογία",
        "Θεοπίστη",
        "Θεοφίλη",
        "Θεοφανία",
        "Θεοφύλακτη",
        "Θεοχαρούλα",
        "Θεόκλεια",
        "Θεώνη",
        "Θηρεσία",
        "Θωμαίς",
        "Ιακωβίνα",
        "Ιγνατία",
        "Ινώ",
        "Ιοκάστη",
        "Ιορδανία",
        "Ιουλία",
        "Ιουλιανή",
        "Ιππολύτη",
        "Ισαβέλλα",
        "Ισιδώρα",
        "Ισμήνη",
        "Ιφιγένεια",
        "Ιωάννα",
        "Ιωσηφίνα",
        "Καλή",
        "Καλλίνικη",
        "Καλλιρρόη",
        "Καλλιρόη",
        "Καλλιόπη",
        "Καλομοίρα",
        "Καλυψώ",
        "Κανέλλα",
        "Καρυοφυλλιά",
        "Κασσάνδρα",
        "Κασσιανή",
        "Κατερίνα",
        "Κερασιά",
        "Κικιλία",
        "Κλαίρη",
        "Κλειώ",
        "Κλεονίκη",
        "Κλεοπάτρα",
        "Κλημεντίνη",
        "Κλυταιμνήστρα",
        "Κοκκώνα",
        "Κομνηνή",
        "Κονδυλία",
        "Κοραλία",
        "Κορνηλία",
        "Κρινιώ",
        "Κρυσταλλένια",
        "Κυβέλη",
        "Κυδωνία",
        "Κυπαρισσία",
        "Κυπριανή",
        "Κυράτσα",
        "Κυριακή",
        "Κωνσταντία",
        "Κωνσταντίνα",
        "Κωστούλα",
        "Κόσμια",
        "Λήδα",
        "Λαζαρία",
        "Λαμπρινή",
        "Λασκαρίνα",
        "Λαυρεντία",
        "Λεμονιά",
        "Λευκοθέα",
        "Λεωνιδιά",
        "Λεώνη",
        "Λητώ",
        "Λουίζα",
        "Λουκία",
        "Λουλουδένια",
        "Λυγερή",
        "Λυδία",
        "Μάνθα",
        "Μάρθα",
        "Μαγδαληνή",
        "Μακρίνα",
        "Μαλαμάτη",
        "Μαλαματένια",
        "Μαλβίνα",
        "Μαντώ",
        "Μαρία",
        "Μαρίνα",
        "Μαργαρίτα",
        "Μαργιέττα",
        "Μαριάνθη",
        "Μαριάννα",
        "Μαριγώ",
        "Μαριλένα",
        "Μαρκέλλα",
        "Μαρωτέσα",
        "Ματίνα",
        "Ματθίλδη",
        "Ματρώνη",
        "Μαύρα",
        "Μελένια",
        "Μελέτια",
        "Μελίνα",
        "Μελπομένη",
        "Μερόπη",
        "Μεταξία",
        "Μηλιά",
        "Μινέρβα",
        "Μιράντα",
        "Μιχαέλα",
        "Μυρσίνη",
        "Μυρτώ",
        "Μόσχα",
        "Νίκη",
        "Ναταλία",
        "Ναταλίνα",
        "Ναυσικά",
        "Νεκταρία",
        "Νερατζιά",
        "Νεφέλη",
        "Νεόκλεια",
        "Νικητία",
        "Νικολέτα",
        "Νικολίτσα",
        "Νομική",
        "Νταίζη",
        "Ντανιέλα",
        "Ξένη",
        "Ξανθή",
        "Ξανθίππη",
        "Οδύσσεια",
        "Ολύμπια",
        "Ουρανία",
        "Πέτρα",
        "Παγώνα",
        "Παναγία",
        "Παναγιώτα",
        "Πανδώρα",
        "Παντελία",
        "Παντούλα",
        "Πανωραία",
        "Παρέσσα",
        "Παρασκευή",
        "Παρθένα",
        "Πασχαλιά",
        "Παταπία",
        "Παυλίνα",
        "Πελαγία",
        "Περικλεία",
        "Περιστέρα",
        "Περσεφόνη",
        "Πηγή",
        "Πηνελόπη",
        "Πιερρίνα",
        "Ποθητή",
        "Πολυνίκη",
        "Πολυξένη",
        "Πολυτίμη",
        "Πολυχρονία",
        "Πολύβια",
        "Πολύδωρα",
        "Πολύμνια",
        "Πουλχερία",
        "Πούλια",
        "Προδρομία",
        "Πωλίνα",
        "Ρέα",
        "Ραλλία",
        "Ρεβέκα",
        "Ρεβέκκα",
        "Ρεγγίνα",
        "Ρηγούλα",
        "Ροδάνθη",
        "Ροδαμάνθη",
        "Ροδιά",
        "Ροδόκλεια",
        "Ρουμπίνη",
        "Ρούσα",
        "Ρωξάνη",
        "Ρόζα",
        "Σάρρα",
        "Σαββούλα",
        "Σαλώμη",
        "Σαπφώ",
        "Σεβαστή",
        "Σεβαστιανή",
        "Σελήνη",
        "Σεμίνα",
        "Σεραφεία",
        "Σμαράγδα",
        "Σουλτάνα",
        "Σουμέλα",
        "Σοφία",
        "Σπάρτη",
        "Σπυράννα",
        "Σπυριδούλα",
        "Στέλλα",
        "Σταματίνα",
        "Σταυρούλα",
        "Στεργιανή",
        "Στεργιαννώ",
        "Στεφανία",
        "Στυλιανή",
        "Συμέλα",
        "Συμεωνία",
        "Συμεώνη",
        "Σωζούσα",
        "Σωτηρία",
        "Σωφρονία",
        "Ταξιαρχία",
        "Τατιάνα",
        "Τερψιχόρη",
        "Τζένη",
        "Τιμοθέα",
        "Τριαντάφυλλη",
        "Τριανταφυλλιά",
        "Τρισεύγενη",
        "Τρυφωνία",
        "Τσαμπίκα",
        "Υακίνθη",
        "Υβόννη",
        "Υπαπαντή",
        "Φαίδρα",
        "Φανή",
        "Φανουρία",
        "Φεβρωνία",
        "Φερενίκη",
        "Φιλίππα",
        "Φιλαρέτη",
        "Φιλιππία",
        "Φιλιώ",
        "Φιλοθέη",
        "Φιλομήλα",
        "Φλωρίνα",
        "Φλωρεντία",
        "Φλώρα",
        "Φοίβη",
        "Φραντζέσκα",
        "Φρειδερίκη",
        "Φρύνη",
        "Φωτεινή",
        "Χάιδω",
        "Χάρη",
        "Χαρά",
        "Χαρίκλεια",
        "Χαραλαμπία",
        "Χιονιά",
        "Χλόη",
        "Χριστίνα",
        "Χριστιάνα",
        "Χριστοδούλα",
        "Χριστοφόρα",
        "Χριστόφιλη",
        "Χρυσάνθη",
        "Χρυσή",
        "Χρυσαυγή",
        "Χρυσαφένια",
        "Χρυσοβαλάντου",
        "Χρυσοβαλάντω",
        "Χρυσούλα",
        "Χρυσόστομη",
        "Όλγα",
    )

    first_names = first_names_male + first_names_female

    last_names_male = (
        "Αβαγιανός",
        "Αβραμίδης",
        "Αβραμιώτης",
        "Αγαλιώτης",
        "Αγγελάκος",
        "Αγγελής",
        "Αγγελίδης",
        "Αγγελίκας",
        "Αγγελόπουλος",
        "Αγκυρόπουλος",
        "Αδαμόπουλος",
        "Αετόπουλος",
        "Αθανασάκης",
        "Αθανασόπουλος",
        "Ακαλίδης",
        "Ακριτίδης",
        "Ακριώτης",
        "Αλατζάκης",
        "Αλαφάκης",
        "Αλεξανδρόπουλος",
        "Αλεξόπουλος",
        "Αμπατζιάνης",
        "Αμπλιάνιτης",
        "Αμυγδαλάκης",
        "Αναστασάκης",
        "Αναστασίου",
        "Αναστασόπουλος",
        "Αναστόπουλος",
        "Ανδρεανίδης",
        "Ανδριανός",
        "Ανδρικόπουλος",
        "Ανδριόπουλος",
        "Ανδριώτης",
        "Ανδρουλάκης",
        "Ανδρουλιδάκης",
        "Αντωνάκος",
        "Αντωνέας",
        "Αντωνίου",
        "Αντωνιάδης",
        "Αντωνόπουλος",
        "Αξαόπουλος",
        "Αξιώτης",
        "Αποστολάκης",
        "Αποστολίδης",
        "Αποστολακάκης",
        "Αποστολόπουλος",
        "Αραμπατζής",
        "Αργυρής",
        "Αργυρίου",
        "Αργυρόπουλος",
        "Αρμένης",
        "Αρχαυλής",
        "Ασαρίδης",
        "Ασημακόπουλος",
        "Ασημόπουλος",
        "Αυγουστής",
        "Αφρουδάκης",
        "Βάρσος",
        "Βάσσης",
        "Βαβουλίδης",
        "Βαβουράκης",
        "Βακαλάκης",
        "Βακαλής",
        "Βαλαβάνης",
        "Βαλασίδης",
        "Βαλτάς",
        "Βαμβακάς",
        "Βανδώρος",
        "Βαρακλής",
        "Βαρδάκης",
        "Βαρσάμης",
        "Βασιλάκης",
        "Βασιλείου",
        "Βασιλογιάννης",
        "Βαχουθιανάκης",
        "Βαϊτσόπουλος",
        "Βελεντζάς",
        "Βιδαλάκης",
        "Βιλδός",
        "Βιολάτος",
        "Βιτσαξής",
        "Βλάχος",
        "Βλαχονικολέας",
        "Βλησαρούλης",
        "Βολικάκης",
        "Βορλόκας",
        "Βουτσάς",
        "Βουτσελας",
        "Βούκας",
        "Βούλγαρης",
        "Βούλκος",
        "Βούρας",
        "Βώσσος",
        "Γάτος",
        "Γαβριδάκης",
        "Γαλατούλας",
        "Γαρουφαλής",
        "Γαρυφαλίδης",
        "Γενετζάκης",
        "Γεννηματάς",
        "Γεντίμης",
        "Γεράρδης",
        "Γεροδήμος",
        "Γερόπουλος",
        "Γεωργακόπουλος",
        "Γεωργαλάς",
        "Γεωργαλής",
        "Γεωργούδης",
        "Γεωργούλας",
        "Γιαννάκης",
        "Γιαννέλος",
        "Γιαννές",
        "Γιαννακέας",
        "Γιαννακίτσας",
        "Γιαννακουδάκης",
        "Γιαννακόπουλος",
        "Γιαννούκος",
        "Γιαννόπουλος",
        "Γιαπατζής",
        "Γιασημάκης",
        "Γιατρομανωλάκης",
        "Γιωτάκης",
        "Γιώτης",
        "Γκάγκας",
        "Γκίκας",
        "Γκίνης",
        "Γκαγκαουδάκης",
        "Γκαλίου",
        "Γκανάτσιος",
        "Γκατζογιάννης",
        "Γκικόπουλος",
        "Γκιολδελής",
        "Γκιτσάκης",
        "Γκουτζαμάνης",
        "Γκούβελος",
        "Γκούσκος",
        "Γκότσης",
        "Γουργουλής",
        "Γούσιος",
        "Γρίβας",
        "Γραμματικόπουλος",
        "Γραμματικός",
        "Γρατσιάς",
        "Γρεβενάρης",
        "Γρετός",
        "Γρηγορίου",
        "Γρηγοριάδης",
        "Γρηγορόπουλος",
        "Δάρας",
        "Δέλιος",
        "Δίγκας",
        "Δακαναλής",
        "Δανέζης",
        "Δανελής",
        "Δανιηλίδης",
        "Δερμιτζάκης",
        "Δεσύλλας",
        "Δημησκής",
        "Δημητρίου",
        "Δημητρόπουλος",
        "Δημοβελής",
        "Δημόπουλος",
        "Διακάκης",
        "Διαμαντής",
        "Δινεζάκης",
        "Δουβίκας",
        "Δουβρόπουλος",
        "Δουκάς",
        "Δουκατζής",
        "Δουλάμης",
        "Δουλγεράκης",
        "Δουμάς",
        "Δουράνης",
        "Δούνης",
        "Δραζιώτης",
        "Δρακάκης",
        "Δρακόπουλος",
        "Δρουλιάς",
        "Δόβας",
        "Δόσης",
        "Ελευθερίου",
        "Εμπορόπουλος",
        "Εσπερίδης",
        "Ευαγγελάτος",
        "Ευαγγελινός",
        "Ευκαρπίδης",
        "Ευστρατόπουλος",
        "Ευταξιάς",
        "Έψιμος",
        "Ζαραφέτας",
        "Ζαφείρης",
        "Ζαχαρίου",
        "Ζενεμπίσης",
        "Ζευγίτης",
        "Ζηδιανάκης",
        "Ζηματίκας",
        "Ζηρός",
        "Ζιάκας",
        "Ζιώγος",
        "Ζολώτας",
        "Ζορμπάς",
        "Ζουκής",
        "Ζουλούμης",
        "Ζούνης",
        "Ζτούκος",
        "Ζυγούρης",
        "Ζώνιος",
        "Ζώτος",
        "Θεοδοσίου",
        "Θεοδωρικάκος",
        "Θεοδωρόπουλος",
        "Θεολόγος",
        "Θεοχάρης",
        "Θηβαίος",
        "Θωμάς",
        "Θωμόπουλος",
        "Ιακωβάκης",
        "Ιατρόπουλος",
        "Ιντζές",
        "Ισάρης",
        "Ισέρης",
        "Ιωσηφίδης",
        "Κίσσας",
        "Καβούρης",
        "Καζανόπουλος",
        "Κακαβός",
        "Κακατσός",
        "Κακοσαίος",
        "Καλαμάρας",
        "Καλαμαράκης",
        "Καλαμπαλίκης",
        "Καλαπόδης",
        "Καλαργυρός",
        "Καλαϊτζάκης",
        "Καλιάμπος",
        "Καλιτσουνάκης",
        "Καμπάκας",
        "Καμπερίδης",
        "Καμποσάκης",
        "Καναβός",
        "Κανελλόπουλος",
        "Καπατσώρης",
        "Καπετάνιος",
        "Καπούνης",
        "Καράμπας",
        "Καράνης",
        "Καραΐσκος",
        "Καραγιάννης",
        "Καραγρηγορίου",
        "Καραδήμος",
        "Καρακάξης",
        "Καρακαστανιάς",
        "Καρακυρίου",
        "Καραλής",
        "Καραμάνος",
        "Καραμσαλής",
        "Καρανίκας",
        "Καρανασίου",
        "Καρανικόλας",
        "Καραντζόπουλος",
        "Καρατζίκος",
        "Καρατζαφέρης",
        "Καρούντζος",
        "Καρούσος",
        "Καρτάς",
        "Καρυπίδης",
        "Κασούτσας",
        "Καστάνης",
        "Κατάκης",
        "Καταραχιάς",
        "Κατεβάτης",
        "Κατιρτζής",
        "Κατσίπης",
        "Κατσίφος",
        "Κατσαβός",
        "Κατσαμάνης",
        "Κατσαντώνης",
        "Κατσαρός",
        "Κατσιγιάννης",
        "Κατσιλής",
        "Κατσογιάννης",
        "Καφίρης",
        "Καφαντάρης",
        "Καψάλης",
        "Κελαϊδώνης",
        "Κελλάρης",
        "Κερασοβίτης",
        "Κεσαλίδης",
        "Κεσεμίδης",
        "Κεχαγιάς",
        "Κιοσές",
        "Κιουπλιώτης",
        "Κιούσης",
        "Κιτινός",
        "Κλήμης",
        "Κοκορδέλης",
        "Κολοβός",
        "Κολοκάθης",
        "Κολχούρης",
        "Κομκούδης",
        "Κομπολιάς",
        "Κονδυλίδης",
        "Κονιδάρης",
        "Κοντάκος",
        "Κοντογιάννης",
        "Κοντοκώστας",
        "Κοντός",
        "Κορδατζής",
        "Κορμπόπουλος",
        "Κορομήλας",
        "Κοτσαρής",
        "Κοττίκας",
        "Κουβάς",
        "Κουκλατζής",
        "Κουκουβίνος",
        "Κουκουλιάντας",
        "Κουλίδης",
        "Κουλίζος",
        "Κουλουριώτης",
        "Κουμιώτης",
        "Κουράκος",
        "Κουρής",
        "Κουρελής",
        "Κουρκουτάς",
        "Κουρσάρης",
        "Κουρσουμίδης",
        "Κουταλιός",
        "Κουτελιέρης",
        "Κουτεντάκης",
        "Κουτσικόπουλος",
        "Κουτσογιάννης",
        "Κουτσογιάννόπουλος",
        "Κουτσουλής",
        "Κουτσουρέλης",
        "Κουτσούρας",
        "Κουτχιάς",
        "Κούρτης",
        "Κούτρης",
        "Κούτσικος",
        "Κραββαρίτης",
        "Κρεμμύδας",
        "Κριάλης",
        "Κριτσέλης",
        "Κτενίδης",
        "Κυμπάρης",
        "Κυπραίος",
        "Κυπριώτης",
        "Κυρίτσης",
        "Κυργιάκης",
        "Κυριαζής",
        "Κυριακάκης",
        "Κυριακίδης",
        "Κυριατσούλης",
        "Κωνσταντάς",
        "Κωνσταντακόπουλος",
        "Κωνσταντινίδης",
        "Κωνσταντόπουλος",
        "Κωστάκης",
        "Κωστίδης",
        "Κωσταλής",
        "Κωστούλας",
        "Κωστόπουλος",
        "Κωτούλας",
        "Κωτσίδης",
        "Κωτσικόρης",
        "Κόλκας",
        "Κώττας",
        "Λάκκας",
        "Λάλας",
        "Λάππας",
        "Λάτσκος",
        "Λέλεκας",
        "Λαγγούσης",
        "Λαγογιάννης",
        "Λαγοπάτης",
        "Λαζαρίδης",
        "Λαμπρινός",
        "Λαουρδέκης",
        "Λαφατζής",
        "Λεβέντης",
        "Λελεδάκης",
        "Λεμονής",
        "Λεντζίου",
        "Λιανάκης",
        "Λιβανός",
        "Λιθοξοΐδης",
        "Λιούτας",
        "Λιτίνας",
        "Λιόλιος",
        "Λουλάκης",
        "Λουπασάκης",
        "Λουράντος",
        "Λυγκούρας",
        "Λυμπέρης",
        "Λώλος",
        "Μάνδαλος",
        "Μάνδρος",
        "Μάνος",
        "Μάργαρης",
        "Μάρρας",
        "Μάστορας",
        "Μίσχος",
        "Μίχος",
        "Μαγκούφης",
        "Μαζαράκης",
        "Μακαριάδης",
        "Μακρής",
        "Μακρυγιάννης",
        "Μακρυκώστας",
        "Μαμμής",
        "Μανίκας",
        "Μανελίδης",
        "Μανιώτης",
        "Μανουσέλης",
        "Μανουσιάδης",
        "Μανούκας",
        "Μαντάρης",
        "Μαντάς",
        "Μαντζουράνης",
        "Μαντζώρος",
        "Μανωλάκης",
        "Μανωλέας",
        "Μαραγκός",
        "Μαρακάς",
        "Μαργαρώνης",
        "Μαρκόπουλος",
        "Μασγαλάς",
        "Μαστρογιάννης",
        "Μαστρογιώργης",
        "Μασόπουλος",
        "Ματσούκας",
        "Μαυρικάκης",
        "Μαυρογονάτος",
        "Μαυροειδάκος",
        "Μαυρομανωλάκης",
        "Μαυρομμάτης",
        "Μαυρουδής",
        "Μαυρούτσος",
        "Μελιτσόπουλος",
        "Μεταξάς",
        "Μεϊμάρης",
        "Μηλιώρης",
        "Μητρίδης",
        "Μητρόπουλος",
        "Μητσόπουλος",
        "Μιχαηλίδης",
        "Μιχαλάκης",
        "Μιχαλέλλης",
        "Μοσχόπουλος",
        "Μουσελίμης",
        "Μουτουσίδης",
        "Μπέκος",
        "Μπίλλας",
        "Μπαγανάς",
        "Μπακλάβας",
        "Μπακοστεργίου",
        "Μπαλάσκας",
        "Μπαλουκίδης",
        "Μπαλταγιάννης",
        "Μπαλτζής",
        "Μπαντές",
        "Μπαντής",
        "Μπερεδήμας",
        "Μπερμπατιώτης",
        "Μπλανάς",
        "Μπλιατσίου",
        "Μποζίκης",
        "Μποτσώλης",
        "Μποτώνης",
        "Μπουλούκος",
        "Μπουρλής",
        "Μποφός",
        "Μπούκος",
        "Μπούσιος",
        "Μπραζιώτης",
        "Μπότης",
        "Μυλωνάς",
        "Μυσιρλής",
        "Μυτελέτσης",
        "Μωραΐτης",
        "Μωρός",
        "Μόκας",
        "Μόναχας",
        "Νάστατος",
        "Νάστος",
        "Νέλος",
        "Νανούρης",
        "Νασίκας",
        "Νασιόπουλος",
        "Νικητόπουλος",
        "Νικολαΐδης",
        "Νικολόπουλος",
        "Νικουλής",
        "Νιτσοτόλης",
        "Νούσης",
        "Νταβάς",
        "Ντουλιάς",
        "Ντόβας",
        "Ντόκος",
        "Ντότης",
        "Ξανθάκης",
        "Ξηρογιάννης",
        "Ξηρός",
        "Ορφανάκης",
        "Ορφανιώτης",
        "Ότσος",
        "Πάγκαλος",
        "Πάνος",
        "Πάντος",
        "Πέππας",
        "Πέτσας",
        "Πίππας",
        "Πίσσιος",
        "Πίτσης",
        "Παλαιολόγος",
        "Παληός",
        "Παλλάς",
        "Παναγιωτακόπουλος",
        "Πανδής",
        "Πανούσης",
        "Πανταζής",
        "Παντζέκος",
        "Παντζαρτζίδης",
        "Παπαγεωργίου",
        "Παπαγιάννης",
        "Παπαγιαννακόπουλος",
        "Παπαγιαννόπουλος",
        "Παπαδάκης",
        "Παπαδημητράκης",
        "Παπαδημητριάδης",
        "Παπαδόπουλος",
        "Παπαευαγγελίου",
        "Παπαθανασίου",
        "Παπαθεοδοσίου",
        "Παπαπανός",
        "Παπαροϊδάμης",
        "Παπαστεργίου",
        "Παπατρέχας",
        "Παπαφώτης",
        "Παπουδής",
        "Παπουλής",
        "Παππάς",
        "Παρασκευόπουλος",
        "Παργανάς",
        "Παρούσης",
        "Πασσαλίδης",
        "Πατελής",
        "Πατμανίδης",
        "Πατσούρας",
        "Περάκης",
        "Περδίκης",
        "Περδικάκης",
        "Περιστερόπουλος",
        "Περπινιάς",
        "Περράκης",
        "Περρώτης",
        "Πετράκης",
        "Πετρίδης",
        "Πετριτάκης",
        "Πετρογιάννης",
        "Πετρόπουλος",
        "Πευκιανάκης",
        "Πιάγκος",
        "Πικούνης",
        "Πικρός",
        "Πιπεράκης",
        "Πιπερίγκος",
        "Πισχινάς",
        "Πιτερός",
        "Πιτσάκης",
        "Πιτσολής",
        "Πλακωτάρης",
        "Πλιάτσικας",
        "Πολυζωάκης",
        "Πολυχρονίδης",
        "Πολυχρονόπουλος",
        "Πολυχρόνης",
        "Πορίχης",
        "Πουλημένος",
        "Πουλιέζος",
        "Πουλογιαννόπουλος",
        "Πουφτσής",
        "Προβής",
        "Πυλαρινός",
        "Ράλλης",
        "Ράπτης",
        "Ρέγκας",
        "Ρέντας",
        "Ρέντζος",
        "Ρέππος",
        "Ρήγας",
        "Ρήνος",
        "Ρίγκος",
        "Ρίζος",
        "Ρίσβας",
        "Ραγκούσης",
        "Ραδοβάλης",
        "Ραφιός",
        "Ραχμανίδης",
        "Ραχωβίτσας",
        "Ριζούλης",
        "Ρουπακάς",
        "Ρουσιανός",
        "Ροϊδούλης",
        "Ρωμαίου",
        "Ρόγαρης",
        "Ρόδης",
        "Ρόκας",
        "Σάτλας",
        "Σίδερης",
        "Σακελλαρίου",
        "Σαλίχος",
        "Σαλταούρας",
        "Σαμακίδης",
        "Σαμανίδης",
        "Σαμαράς",
        "Σαουλίδης",
        "Σαρίκας",
        "Σαραντινός",
        "Σαραφίδης",
        "Σαρρός",
        "Σγουρός",
        "Σδραλλής",
        "Σεβδάς",
        "Σεφέκος",
        "Σιγανός",
        "Σιδηρόπουλος",
        "Σικαλίδης",
        "Σιτόπουλος",
        "Σιώμος",
        "Σιώρης",
        "Σκαρλάτος",
        "Σκαρπέτας",
        "Σκορδάκης",
        "Σκουλαρίδης",
        "Σκρέκας",
        "Σκρίμπας",
        "Σκόρδος",
        "Σμαρδάς",
        "Σμπονιάς",
        "Σμπρίνης",
        "Σμυρνιώτης",
        "Σολακούδης",
        "Σουλιντζής",
        "Σουρμπής",
        "Σοφιανός",
        "Σπάλας",
        "Σπαθόπουλος",
        "Σπανδωνίδης",
        "Σπανουδάκης",
        "Σπανός",
        "Σπασόπουλος",
        "Σπηλιώτης",
        "Σπορδιλής",
        "Σπυριδάκης",
        "Σπυρόπουλος",
        "Σταθάτος",
        "Σταθόπουλος",
        "Σταμάτης",
        "Σταμέλος",
        "Σταματιάδης",
        "Σταμούλης",
        "Σταμόπουλος",
        "Σταυριανός",
        "Σταυρόπουλος",
        "Στεργιαλής",
        "Στεργιούδης",
        "Στοφοριάδης",
        "Στραβοσνίχης",
        "Στόγιος",
        "Συλλίγαρδος",
        "Συργής",
        "Συρρής",
        "Σφούνης",
        "Σφύρλας",
        "Σωτηράλης",
        "Σύκας",
        "Τάρναρης",
        "Τάσιος",
        "Τάχας",
        "Ταβερναράκης",
        "Τακαντζάς",
        "Ταμιωλάκης",
        "Τασιούλας",
        "Ταχμαζίδης",
        "Ταχτσίδης",
        "Τεμουρτζίδης",
        "Τερζής",
        "Τερζίδης",
        "Τζέκος",
        "Τζήκας",
        "Τζαβέλλας",
        "Τζαλλας",
        "Τζανουδάκης",
        "Τζεβελέκος",
        "Τζιάβας",
        "Τζιάρας",
        "Τζινιέρης",
        "Τζιόρτζιος",
        "Τζιώτζης",
        "Τζουβέλης",
        "Τζουμάκης",
        "Τοδώρης",
        "Τολούδης",
        "Τορομίδης",
        "Τουρναβίτης",
        "Τραχίλης",
        "Τρεντσίου",
        "Τριαντακωνσταντής",
        "Τριβέλλας",
        "Τσάρκος",
        "Τσέας",
        "Τσέγας",
        "Τσέλιος",
        "Τσέλλος",
        "Τσαγκρασούλης",
        "Τσαγλιώτης",
        "Τσακανίκας",
        "Τσακμάκης",
        "Τσαλαμάνδρης",
        "Τσαμαδός",
        "Τσαμασλίδης",
        "Τσανδήλας",
        "Τσαπραλής",
        "Τσαραμιάδης",
        "Τσατσάνης",
        "Τσεμπερλίδης",
        "Τσεντούρος",
        "Τσιάκος",
        "Τσιάρας",
        "Τσιαμίτας",
        "Τσιαμούρας",
        "Τσιαντάς",
        "Τσιατής",
        "Τσιγαρίδας",
        "Τσικνιάς",
        "Τσιρώνης",
        "Τσιτούρας",
        "Τσομώκος",
        "Τσοπανίδης",
        "Τσουκνίδας",
        "Τσούμος",
        "Τσούπρας",
        "Τσόλκας",
        "Τσότρας",
        "Τσώνης",
        "Τσώτσης",
        "Τυμβίου",
        "Τυράλης",
        "Φαλιέρος",
        "Φανουργάκης",
        "Φειδερόπουλος",
        "Φερεντίνος",
        "Φιλιππάκης",
        "Φιλιππάτος",
        "Φιλιππόπουλος",
        "Φουντζούλας",
        "Φουσιέκης",
        "Φουτσιτζής",
        "Φούσκας",
        "Φραγκόπουλος",
        "Φραντζής",
        "Φρογάκης",
        "Φυδάνης",
        "Φωκάς",
        "Φωκαδελής",
        "Φωτογλίδης",
        "Φωτόπουλος",
        "Χέλιος",
        "Χαβρεδάκης",
        "Χαλατσής",
        "Χαραλάμπους",
        "Χαραλαμπίδης",
        "Χαρισιάδης",
        "Χαρμπίλας",
        "Χαρπαντίδης",
        "Χαρτερός",
        "Χατζαντώνης",
        "Χατζελλής",
        "Χατζηβλασίου",
        "Χατζηγεωργίου",
        "Χατζηγρηγοράκης",
        "Χατζηκύρκος",
        "Χατζησάββας",
        "Χατζησαββίδης",
        "Χατζησταυράκης",
        "Χατζιάρας",
        "Χατζόπουλος",
        "Χαχούδης",
        "Χητός",
        "Χιτός",
        "Χονδρολίδης",
        "Χουδαλάκης",
        "Χουλιάρας",
        "Χουντής",
        "Χουχουλής",
        "Χριστάκης",
        "Χριστάρας",
        "Χριστακόπουλος",
        "Χριστοδουλάκης",
        "Χριστόπουλος",
        "Χρονόπουλος",
        "Χρυσίδης",
        "Χρυσικός",
        "Χρυσοβέργης",
        "Χρυσουλής",
        "Ψάλτης",
        "Ψυλλάκης",
        "Ψυχιάς",
    )

    last_names_female = (
        "Αβραμίδου",
        "Αβραμπέκη",
        "Αγγελάκη",
        "Αγγελίδου",
        "Αγγελουσοπούλου",
        "Αγραφιώτη",
        "Αδαμοπούλου",
        "Αθανασιάδη",
        "Αθανασιάδου",
        "Αλεξανδράκη",
        "Αλεξανδρίδου",
        "Αλεξοπούλου",
        "Αλυσανδράτου",
        "Ανανιάδου",
        "Αναστασάκη",
        "Αναστασίου",
        "Ανεζάκη",
        "Αντωνάκη",
        "Αντωνίου",
        "Αποστολάκη",
        "Αποστολίδου",
        "Αραπάκη",
        "Αραπίδου",
        "Αργυράκη",
        "Αργυρίου",
        "Αργυροπούλου",
        "Αρματά",
        "Αρσενάκη",
        "Αρχάκη",
        "Ασλανίδου",
        "Ασουχίδου",
        "Ασσαργιωτάκη",
        "Ατσαλάκη",
        "Βαΐου",
        "Βαβάση",
        "Βαγενά",
        "Βαζούρα",
        "Βαϊραμίδου",
        "Βακουφτσή",
        "Βαλεντή",
        "Βαλιάκα",
        "Βαλκάνου",
        "Βαλσαμίδου",
        "Βαμβουκάκη",
        "Βαρελίδου",
        "Βαρθαλίτη",
        "Βαρουτίδου",
        "Βαρσάμου",
        "Βασιλάκη",
        "Βασιλείου",
        "Βασιλειάδη",
        "Βασιλοπούλου",
        "Βαφειάδου",
        "Βερβερίδου",
        "Βερβίτη",
        "Βλάσση",
        "Βλαχοδήμου",
        "Βλάχου",
        "Βοσινάκη",
        "Βουλγαρίδου",
        "Βουλτσίδου",
        "Βουτσινά",
        "Βραδή",
        "Βρακά",
        "Βράσκου",
        "Βυζιηνού",
        "Γαβριήλ",
        "Γαβριηλίδη",
        "Γαλανάκη",
        "Γαλάνη",
        "Γαλανοπούλου",
        "Γεροκώστα",
        "Γερούκη",
        "Γεωργακοπούλου",
        "Γεωργαρά",
        "Γεωργή",
        "Γεωργιάδου",
        "Γεωργίτση",
        "Γεωργουλάκη",
        "Γεωργούλα",
        "Γιακαμόζη",
        "Γιαννακουδάκη",
        "Γιανναρά",
        "Γιαννοπούλου",
        "Γιατράκου",
        "Γκάβρου",
        "Γκάγκα",
        "Γκαλίου",
        "Γκιριτζιώνη",
        "Γκόβα",
        "Γκόνη",
        "Γκούβα",
        "Γκούνη",
        "Γούλα",
        "Γούπα",
        "Γραμμένου",
        "Γρηγορίου",
        "Γρηγοριάδου",
        "Γρηγοροπούλου",
        "Γρίβα",
        "Δαγλή",
        "Δαΐκου",
        "Δαμαλά",
        "Δαματοπούλου",
        "Δαμήλου",
        "Δανδανίδου",
        "Δαρδιώτη",
        "Δαρσακλή",
        "Δαυίδ",
        "Δάφνη",
        "Δεδούκου",
        "Δελή",
        "Δερλώπα",
        "Δημακογιάννη",
        "Δημητρίου",
        "Δημητρέλου",
        "Δημητριάδου",
        "Δημοπούλου",
        "Δήμου",
        "Δημτσούδη",
        "Διακουμή",
        "Διαμαντοπούλου",
        "Διοπούλου",
        "Δούβαλη",
        "Δουκίδου",
        "Δουλάμη",
        "Δουλγεράκη",
        "Δουλουφάκη",
        "Δρακάκη",
        "Δρακουλή",
        "Δραμουντάνη",
        "Δρίβα",
        "Δρόσου",
        "Δρυμαλίτου",
        "Δώρη",
        "Ελευθερίου",
        "Εμμανουήλ",
        "Εμμανουηλίδου",
        "Ενωτιάδη",
        "Ευαγγελάκη",
        "Ευαγγελίδη",
        "Ζαβιτσάνου",
        "Ζαννίκου",
        "Ζαρειφοπούλου",
        "Ζαρζάνη",
        "Ζαφείρη",
        "Ζαχαρίου",
        "Ζαχαριουδάκη",
        "Ζεγλίνα",
        "Ζερβά",
        "Ζιάρα",
        "Ζυγούρη",
        "Ζώη",
        "Ζωντανού",
        "Θασίτου",
        "Θεοδοσίου",
        "Θεοδοσιάδου",
        "Θεοδωροπούλου",
        "Θωμάκου",
        "Ιωακείμ",
        "Ιωακειμίδου",
        "Ιωσηφίδου",
        "Καζαντζή",
        "Κάκκα",
        "Κακοτρίχη",
        "Καλαθά",
        "Καλαϊτζοπούλου",
        "Καλαμάρα",
        "Καλδή",
        "Καλέμη",
        "Καλλιάνταση",
        "Καλογιαννάκη",
        "Καλογιάννη",
        "Καλομοίρη",
        "Καλούδη",
        "Καμινάρη",
        "Καμπούρη",
        "Κανελή",
        "Κανελλή",
        "Κανελλοπούλου",
        "Κανταρελή",
        "Καπανταϊδάκη",
        "Καπνιά",
        "Καπουρνιώτη",
        "Καραγιάννη",
        "Καραγιοβάννη",
        "Καραγρηγορίου",
        "Καραθανάση",
        "Καρακυρίου",
        "Καρακωνσταντινού",
        "Καρακώστα",
        "Καραμάνη",
        "Καραμανλή",
        "Καράμπη",
        "Καραμπίνα",
        "Καρανάνου",
        "Καρανασίου",
        "Καραντάνα",
        "Καραογλάνη",
        "Καρατάσου",
        "Καρβέλη",
        "Καργάκου",
        "Καρκαλέτση",
        "Καρκανάκη",
        "Καρολίδου",
        "Καρυδά",
        "Κασκαούτη",
        "Κασμιρλή",
        "Κασσωτάκη",
        "Κατσανίκου",
        "Κατσαντώνη",
        "Κατσαφάδου",
        "Κατσιγιάννη",
        "Κατσιλλή",
        "Κατσιμάλη",
        "Κατσιμάνη",
        "Κατσούλα",
        "Καφαντάρη",
        "Καφφέ",
        "Καχριμανίδη",
        "Καψή",
        "Κεσίση",
        "Κεσκίνη",
        "Κετεσίδου",
        "Κεφαλή",
        "Κιορίδου",
        "Κίτσου",
        "Κλεινάκη",
        "Κοκκινίδου",
        "Κοκκίνου",
        "Κολαΐτου",
        "Κόλλια",
        "Κολτσάκη",
        "Κονιάρη",
        "Κονσούλα",
        "Κοντογεωργάκη",
        "Κοντογιάννη",
        "Κοντού",
        "Κορομπόκη",
        "Κορωνίδου",
        "Κοτρώτσου",
        "Κοτσινά",
        "Κουζουλά",
        "Κουθούρη",
        "Κουκουβά",
        "Κουκουθάκη",
        "Κουλαουσάρη",
        "Κουλουμπού",
        "Κουλοχέρη",
        "Κουμάρα",
        "Κουρλού",
        "Κουτκιά",
        "Κουτουζίδου",
        "Κουτσικούρη",
        "Κουτσιουμάρη",
        "Κουτσοβίδου",
        "Κουτσονίκα",
        "Κουτσούμπεη",
        "Κουτσούμπη",
        "Κουτσουνάκη",
        "Κουτσουρέλη",
        "Κουφάκη",
        "Κοφινάκη",
        "Κυργιά",
        "Κυριακοπούλου",
        "Κυριάκου",
        "Κυριακούλη",
        "Κυριαννάκη",
        "Κυρίτση",
        "Κυρκούδη",
        "Κυρούδη",
        "Κωνσταντινίδου",
        "Κωνσταντοπούλου",
        "Κωστοπούλου",
        "Κωτούλα",
        "Κωτσιονοπούλου",
        "Κώτσου",
        "Λαλαούνη",
        "Λέκκα",
        "Λεντζίου",
        "Λεπίδα",
        "Λιάκου",
        "Λιάνου",
        "Λιναρδάκη",
        "Λιολιοπούλου",
        "Λιόντη",
        "Λιούκα",
        "Λίτσιου",
        "Λογκάκη",
        "Λογοθέτη",
        "Λουμπούτσκου",
        "Λυμαξή",
        "Λυρή",
        "Λύτρα",
        "Μαγκανάρη",
        "Μαγκαφοπούλου",
        "Μαγούλα",
        "Μακρή",
        "Μακροπούλου",
        "Μάλαμα",
        "Μαλίμη",
        "Μαλλή",
        "Μαμαλά",
        "Μανέτα",
        "Μανιάτη",
        "Μανιτάρου",
        "Μανοπούλου",
        "Μανουσοπούλου",
        "Μαντά",
        "Μάντου",
        "Μαράκη",
        "Μάρα",
        "Μαργαριτάκη",
        "Μαργαρίτη",
        "Μαργιά",
        "Μαρκαντωνάκη",
        "Μαρουγιάννη",
        "Μαρτζούκου",
        "Μαρτιάδου",
        "Μασαούτη",
        "Μασιάλα",
        "Μασίκα",
        "Μαστραγγελή",
        "Μαστρογιαννίδου",
        "Ματεντσίδου",
        "Ματσούρη",
        "Μαυρίδου",
        "Μαυραειδή",
        "Μαυρίδη",
        "Μαυροείδη",
        "Μαυροπούλου",
        "Μέλανι",
        "Μενγκ",
        "Μεξή",
        "Μηλιάδου",
        "Μηλιάκη",
        "Μηνά",
        "Μητροπούλου",
        "Μητσοπούλου",
        "Μήτσου",
        "Μιλέα",
        "Μισίδου",
        "Μιχαηλίδου",
        "Μιχαλάρου",
        "Μιχελή",
        "Μιχελακάκη",
        "Μίχου",
        "Μοσχοβάκη",
        "Μουτζούρη",
        "Μπακοστεργίου",
        "Μπακουλή",
        "Μπαλή",
        "Μπαλαμπάνη",
        "Μπαλανίκα",
        "Μπαλάση",
        "Μπαλλή",
        "Μπαλτατζή",
        "Μπαρκούτα",
        "Μπατζάνη",
        "Μπατσάκη",
        "Μπαφέρα",
        "Μπαφίτη",
        "Μπεκάκου",
        "Μπελέκου",
        "Μπενέτου",
        "Μπεσύρη",
        "Μπίκα",
        "Μπιμπίκα",
        "Μπιμπίρη",
        "Μπλιατσίου",
        "Μποζίκη",
        "Μπονέλη",
        "Μπότζα",
        "Μποτζιώρη",
        "Μπούζα",
        "Μπραέσα",
        "Μπρούζου",
        "Μπύρου",
        "Μυλωνίδου",
        "Μυτάρη",
        "Μωραΐτη",
        "Μωυσίδου",
        "Νάντσου",
        "Ναούμ",
        "Νάσσου",
        "Νατσουλή",
        "Νίκα",
        "Νικολάτου",
        "Νικολάου",
        "Νικολοπούλου",
        "Νικολουδάκη",
        "Νταγκαλή",
        "Ντάνου",
        "Ντανώλα",
        "Ντζιαβίδα",
        "Ντόβα",
        "Ντότση",
        "Ντριβαλά",
        "Νώε",
        "Ξανθοπούλου",
        "Ξενάκη",
        "Ξενίδη",
        "Ξένου",
        "Ξηρίδου",
        "Ξηροδήμα",
        "Ξηροτύρη",
        "Ξυγκάκου",
        "Οικονομοπούλου",
        "Οικονόμου",
        "Ορφανίδου",
        "Παλαιολογοπούλου",
        "Παλαμπουγιούκη",
        "Παλιεράκη",
        "Παλιούρα",
        "Παναγιωτακοπούλου",
        "Παναγιώτου",
        "Πανκίδου",
        "Πανοπούλου",
        "Πάνου",
        "Πανταζή",
        "Πάντζιου",
        "Παντίσκα",
        "Πάντου",
        "Παπαγεωργίου",
        "Παπαδήμα",
        "Παπαδημητροπούλου",
        "Παπαδοπούλου",
        "Παπαευαγγελίου",
        "Παπαευαγγέλου",
        "Παπαθανασίου",
        "Παπαθεοδοσίου",
        "Παπαθωμά",
        "Παπακωνσταντίνου",
        "Παπακώστα",
        "Παπανάνου",
        "Παπανδρέου",
        "Παπανδρικοπούλου",
        "Παπανικολάου",
        "Παπανώτα",
        "Παπασπηλιωτοπούλου",
        "Παπασταύρου",
        "Παπαστεργίου",
        "Παπατζήκα",
        "Παπαχρήστου",
        "Παπουτσοπούλου",
        "Παππά",
        "Παράνου",
        "Παρασκευά",
        "Πατελλή",
        "Πατινιωτάκη",
        "Πατσουρέα",
        "Παυλάκη",
        "Παυλή",
        "Παυλίδου",
        "Πεμούση",
        "Περουλάκη",
        "Πετράκη",
        "Πετρίδου",
        "Πετροσιάν",
        "Πέτρου",
        "Πέτση",
        "Πετσιά",
        "Πέττα",
        "Πιπερίδη",
        "Πισκοπάνη",
        "Πίσπα",
        "Πλατάκη",
        "Πολατίδου",
        "Πολέμη",
        "Πολίτου",
        "Πορφυριάδου",
        "Ποσάντζη",
        "Ποταμιάνου",
        "Πουλή",
        "Πουλιάση",
        "Πουλίδα",
        "Πουρνάρα",
        "Πρέκα",
        "Προύβα",
        "Πυροβόλου",
        "Ραδιοπούλου",
        "Ραυτοπούλου",
        "Ρέππα",
        "Ρόγγα",
        "Ροδίτου",
        "Ρόκκα",
        "Ρούσσου",
        "Ρωμαίου",
        "Σαββάκη",
        "Σακελλαρίου",
        "Σακκή",
        "Σαλέμη",
        "Σαμπάνη",
        "Σαμτανίδου",
        "Σάουερ",
        "Σαπρίκη",
        "Σαριδάκη",
        "Σαρρή",
        "Σγουρένα",
        "Σδούκου",
        "Σεβαστού",
        "Σελινοπούλου",
        "Σεμπέπου",
        "Σηκωτίδου",
        "Σίββα",
        "Σιδηροπούλου",
        "Σιμητοπούλου",
        "Σιμιτζή",
        "Σιόλου",
        "Σιούτα",
        "Σκαβέντζου",
        "Σκασίλα",
        "Σκαφτούρου",
        "Σκοτάδη",
        "Σκούμπρου",
        "Σκρεμμύδα",
        "Σκυλογιάννη",
        "Σμιτ",
        "Σοκολάκη",
        "Σολωμίδου",
        "Σόφρα",
        "Σπαθάρη",
        "Σπανίδου",
        "Σπανοχριστοδούλου",
        "Σπασέγκου",
        "Σπηλιάδου",
        "Σπυριδάκη",
        "Σταθά",
        "Σταματούκου",
        "Σταμέλου",
        "Σταμούλη",
        "Σταυρίδου",
        "Σταύρου",
        "Στεφάνου",
        "Στούμπου",
        "Στρατογιάννη",
        "Στρούμπα",
        "Στυλιανίδου",
        "Συβιλιά",
        "Συμεωνίδου",
        "Συνοδινού",
        "Συρμού",
        "Σύψα",
        "Σφακιανάκη",
        "Σωτηροπούλου",
        "Ταμπορρίνο",
        "Τάντου",
        "Ταξίδου",
        "Τάσση",
        "Τάτση",
        "Ταυλαρίδου",
        "Ταφραλή",
        "Τζάγκα",
        "Τζαναβάρα",
        "Τζιγκούρα",
        "Τζιόβα",
        "Τζιρατούδη",
        "Τζιωρτζή",
        "Τόγια",
        "Τόλη",
        "Τομπουλίδου",
        "Τόμπρη",
        "Τοπαλή",
        "Τοσούνη",
        "Τουλάκη",
        "Τουλούπη",
        "Τουρνά",
        "Τραγούστη",
        "Τρεντσίου",
        "Τριανταφύλλου",
        "Τρίκα",
        "Τριφτανίδου",
        "Τρομπούκη",
        "Τσάκη",
        "Τσακαλάκου",
        "Τσακίρη",
        "Τσαμοπούλου",
        "Τσαμπαλή",
        "Τσαμπούρη",
        "Τσαμτσούρη",
        "Τσανάκα",
        "Τσαντίδου",
        "Τσάτη",
        "Τσαχάκη",
        "Τσέτου",
        "Τσετσέρη",
        "Τσικνή",
        "Τσικρίκα",
        "Τσίμη",
        "Τσιομπάνη",
        "Τσιούπρα",
        "Τσιπλίκωφ",
        "Τσιωλξ",
        "Τσουκιά",
        "Τσουνάκου",
        "Τσουράκη",
        "Τσούρα",
        "Τσώνη",
        "Τυμβίου",
        "Υφαντή",
        "Φαββάτα",
        "Φαρμάκη",
        "Φασατάκη",
        "Φασουλή",
        "Φασουλίδου",
        "Φειζατίδου",
        "Φιδάνη",
        "Φιλιάγκου",
        "Φιλίππου",
        "Φίλκα",
        "Φλασκή",
        "Φουρκιώτη",
        "Φραγκιαδάκη",
        "Φραγκουδάκη",
        "Φρονιμάκη",
        "Φυτιλή",
        "Φωλιά",
        "Φωτακοπούλου",
        "Φωτιάδου",
        "Χαλαντζούκα",
        "Χαλβατζή",
        "Χαλκίδου",
        "Χαμαλίδου",
        "Χανταμπή",
        "Χαντζή",
        "Χαραλαμπίδου",
        "Χασάπη",
        "Χατζή",
        "Χατζηβλασίου",
        "Χατζηγεωργίου",
        "Χατζηδάκη",
        "Χατζημιχαήλ",
        "Χατζηφώτη",
        "Χατζηχαρίστου",
        "Χιωτίδου",
        "Χολέβα",
        "Χονδρούδη",
        "Χοντζιά",
        "Χορόζη",
        "Χορτάτου",
        "Χουρζαμάνη",
        "Χρήστου",
        "Χριστογιάννη",
        "Χριστοδούλου",
        "Χριστοπούλου",
        "Χριστοφόρη",
        "Χρονοπούλου",
        "Χρυσανθακοπούλου",
        "Χρυσάφη",
        "Χρυσικάκη",
        "Χωριανοπούλου",
        "Χωρινού",
        "Ψυρρή",
        "Ψυχάρη",
    )

    last_names = last_names_male + last_names_female
